@@ -1,7 +1,7 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/mpmath.h,v 1.11 2006/03/28 19:23:33 richb Exp $
+/*  $Header$
  *
- *  Copyright (c) 1987-2006 Sun Microsystems, Inc. All Rights Reserved.
+ *  Copyright (c) 1987-2007 Sun Microsystems, Inc. All Rights Reserved.
  *           
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ void calc_not(int t[MP_SIZE], int s1[MP_SIZE]);
 void calc_rand(int t[MP_SIZE]);
 void calc_u32(int s1[MP_SIZE], int t1[MP_SIZE]);
 void calc_u16(int s1[MP_SIZE], int t1[MP_SIZE]);
-void calc_percent(int s1[MP_SIZE], int s2[MP_SIZE], int t1[MP_SIZE]);
+void calc_percent(int s1[MP_SIZE], int t1[MP_SIZE]);
 void calc_inv(int s1[MP_SIZE], int t1[MP_SIZE]);
 void calc_tenpowx(int s1[MP_SIZE], int t1[MP_SIZE]);
 void calc_xpowy(int MPx[MP_SIZE], int MPy[MP_SIZE], int MPres[MP_SIZE]);
